package nl.iobyte.themepark.commands;

import nl.iobyte.commandapi.CommandFactory;
import nl.iobyte.commandapi.interfaces.ICommandExecutor;
import nl.iobyte.commandapi.middlewares.PermissionMiddleware;
import nl.iobyte.themepark.ThemePark;
import nl.iobyte.themepark.commands.executors.ConsoleExecutor;
import nl.iobyte.themepark.commands.executors.PlayerExecutor;
import nl.iobyte.themepark.commands.subcommands.HelpCommand;
import nl.iobyte.themepark.commands.subcommands.ItemCommand;
import nl.iobyte.themepark.commands.subcommands.MenuCommand;
import nl.iobyte.themepark.commands.subcommands.attraction.AttractionCommands;
import nl.iobyte.themepark.commands.subcommands.region.RegionCommands;
import nl.iobyte.themepark.commands.subcommands.ridecount.RideCountCommands;
import nl.iobyte.themepark.commands.subcommands.status.StatusCommands;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

public class ThemeParkCommand {

    //Load command data
    public ThemeParkCommand() {
        CommandFactory factory = new CommandFactory("themepark");
        factory.addSubCommand(new HelpCommand(factory))
                .addSubCommand(new MenuCommand());

        //Admin
        factory.addSubCommand(new ItemCommand());

        //Region
        RegionCommands.load(factory);

        //Attraction
        AttractionCommands.load(factory);

        //Status
        StatusCommands.load(factory);

        //RideCount
        RideCountCommands.load(factory);

        //Middleware
        factory.addMiddleware(new PermissionMiddleware());

        //Register command
        ThemePark.getInstance().getCommand(factory.getName()).setExecutor((sender, command, s, args) -> {
            ICommandExecutor executor = new ConsoleExecutor(sender);
            if(sender instanceof Player)
                executor = new PlayerExecutor((Player) sender);

            factory.onCommand(executor, args);
            return true;
        });
    }

}
